Interface: BarControllerDatasetOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: BarControllerDatasetOptions

## # Hierarchy

- `ControllerDatasetOptions`

- `ScriptableAndArrayOptions`<`BarOptions`, `ScriptableContext`<`"bar"`>>

- `ScriptableAndArrayOptions`<`CommonHoverOptions`, `ScriptableContext`<`"bar"`>>

- `AnimationOptions`<`"bar"`>

  ↳ `BarControllerDatasetOptions`

## # Properties

### # animation

• animation: `false` | `AnimationSpec`<`"bar"`> & { `onComplete?`: (`event`: `AnimationEvent`) => `void` ; `onProgress?`: (`event`: `AnimationEvent`) => `void` }

#### # Inherited from

AnimationOptions.animation

#### # Defined in

index.esm.d.ts:1640
(opens new window)

### # animations

• animations: `AnimationsSpec`<`"bar"`>

#### # Inherited from

AnimationOptions.animations

#### # Defined in

index.esm.d.ts:1650
(opens new window)

### # backgroundColor

• backgroundColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"bar"`>>

#### # Inherited from

ScriptableAndArrayOptions.backgroundColor

#### # Defined in

index.esm.d.ts:1696
(opens new window)

### # barPercentage

• barPercentage: `number`

Percent (0-1) of the available width each bar should be within the category width. 1.0 will take the whole category width and put the bars right next to each other.

`default` 0.9

#### # Defined in

index.esm.d.ts:109
(opens new window)

### # barThickness

• barThickness: `number` | `"flex"`

Manually set width of each bar in pixels. If set to 'flex', it computes "optimal" sample widths that globally arrange bars side by side. If not set (default), bars are equally sized based on the smallest interval.

#### # Defined in

index.esm.d.ts:119
(opens new window)

### # base

• base: `ScriptableAndArray`<`number`, `ScriptableContext`<`"bar"`>>

The base value for the bar in data units along the value axis.

#### # Inherited from

ScriptableAndArrayOptions.base

#### # Defined in

index.esm.d.ts:1990
(opens new window)

### # borderColor

• borderColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"bar"`>>

#### # Inherited from

ScriptableAndArrayOptions.borderColor

#### # Defined in

index.esm.d.ts:1695
(opens new window)

### # borderRadius

• borderRadius: `ScriptableAndArray`<`number` | `BorderRadius`, `ScriptableContext`<`"bar"`>>

Border radius

`default` 0

#### # Inherited from

ScriptableAndArrayOptions.borderRadius

#### # Defined in

index.esm.d.ts:2002
(opens new window)

### # borderSkipped

• borderSkipped: `ScriptableAndArray`<`boolean` | `"start"` | `"end"` | `"left"` | `"right"` | `"bottom"` | `"top"` | `"middle"`, `ScriptableContext`<`"bar"`>>

Skipped (excluded) border: 'start', 'end', 'left', 'right', 'bottom', 'top', 'middle', false (none) or true (all).

`default` 'start'

#### # Inherited from

ScriptableAndArrayOptions.borderSkipped

#### # Defined in

index.esm.d.ts:1996
(opens new window)

### # borderWidth

• borderWidth: `ScriptableAndArray`<`number` | { `bottom?`: `number` ; `left?`: `number` ; `right?`: `number` ; `top?`: `number` }, `ScriptableContext`<`"bar"`>>

Width of the border, number for all sides, object to specify width for each side specifically

`default` 0

#### # Inherited from

ScriptableAndArrayOptions.borderWidth

#### # Defined in

index.esm.d.ts:2015
(opens new window)

### # categoryPercentage

• categoryPercentage: `number`

Percent (0-1) of the available width each category should be within the sample width.

`default` 0.8

#### # Defined in

index.esm.d.ts:114
(opens new window)

### # clip

• clip: `number` | `false` | `ChartArea`

How to clip relative to chartArea. Positive value allows overflow, negative value clips that many pixels inside chartArea. 0 = clip at chartArea. Clipping can also be configured per side: clip: {left: 5, top: false, right: -2, bottom: 0}

#### # Inherited from

ControllerDatasetOptions.clip

#### # Defined in

index.esm.d.ts:70
(opens new window)

### # hidden

• hidden: `boolean`

Configures the visibility state of the dataset. Set it to true, to hide the dataset from the chart.

`default` false

#### # Inherited from

ControllerDatasetOptions.hidden

#### # Defined in

index.esm.d.ts:88
(opens new window)

### # hoverBackgroundColor

• hoverBackgroundColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"bar"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBackgroundColor

#### # Defined in

index.esm.d.ts:1702
(opens new window)

### # hoverBorderColor

• hoverBorderColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"bar"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBorderColor

#### # Defined in

index.esm.d.ts:1701
(opens new window)

### # hoverBorderWidth

• hoverBorderWidth: `ScriptableAndArray`<`number`, `ScriptableContext`<`"bar"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBorderWidth

#### # Defined in

index.esm.d.ts:1700
(opens new window)

### # indexAxis

• indexAxis: `"x"` | `"y"`

The base axis of the chart. 'x' for vertical charts and 'y' for horizontal charts.

`default` 'x'

#### # Inherited from

ControllerDatasetOptions.indexAxis

#### # Defined in

index.esm.d.ts:66
(opens new window)

### # inflateAmount

• inflateAmount: `ScriptableAndArray`<`number` | `"auto"`, `ScriptableContext`<`"bar"`>>

Amount to inflate the rectangle(s). This can be used to hide artifacts between bars. Unit is pixels. 'auto' translates to 0.33 pixels when barPercentage * categoryPercentage is 1, else 0.

`default` 'auto'

#### # Inherited from

ScriptableAndArrayOptions.inflateAmount

#### # Defined in

index.esm.d.ts:2009
(opens new window)

### # label

• label: `string`

The label for the dataset which appears in the legend and tooltips.

#### # Inherited from

ControllerDatasetOptions.label

#### # Defined in

index.esm.d.ts:74
(opens new window)

### # maxBarThickness

• maxBarThickness: `number`

Set this to ensure that bars are not sized thicker than this.

#### # Defined in

index.esm.d.ts:124
(opens new window)

### # minBarLength

• minBarLength: `number`

Set this to ensure that bars have a minimum length in pixels.

#### # Defined in

index.esm.d.ts:129
(opens new window)

### # normalized

• normalized: `boolean`

Chart.js is fastest if you provide data with indices that are unique, sorted, and consistent across datasets and provide the normalized: true option to let Chart.js know that you have done so.

#### # Inherited from

ControllerDatasetOptions.normalized

#### # Defined in

index.esm.d.ts:58
(opens new window)

### # order

• order: `number`

The drawing order of dataset. Also affects order for stacking, tooltip and legend.

#### # Inherited from

ControllerDatasetOptions.order

#### # Defined in

index.esm.d.ts:78
(opens new window)

### # parsing

• parsing: `false` | { [key: string]: `string`; }

How to parse the dataset. The parsing can be disabled by specifying parsing: false at chart options or dataset. If parsing is disabled, data must be sorted and in the formats the associated chart type and scales use internally.

#### # Inherited from

ControllerDatasetOptions.parsing

#### # Defined in

index.esm.d.ts:49
(opens new window)

### # pointStyle

• pointStyle: `PointStyle`

Point style for the legend

`default` 'circle;

#### # Defined in

index.esm.d.ts:135
(opens new window)

### # stack

• stack: `string`

The ID of the group to which this dataset belongs to (when stacked, each group will be a separate stack).

#### # Inherited from

ControllerDatasetOptions.stack

#### # Defined in

index.esm.d.ts:83
(opens new window)

### # transitions

• transitions: `TransitionsSpec`<`"bar"`>

#### # Inherited from

AnimationOptions.transitions

#### # Defined in

index.esm.d.ts:1651
(opens new window)

### # xAxisID

• xAxisID: `string`

The ID of the x axis to plot this dataset on.

#### # Defined in

index.esm.d.ts:99
(opens new window)

### # yAxisID

• yAxisID: `string`

The ID of the y axis to plot this dataset on.

#### # Defined in

index.esm.d.ts:103
(opens new window)